summaryrefslogtreecommitdiffstats
path: root/src/knowitapp.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/knowitapp.h')
-rw-r--r--src/knowitapp.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/knowitapp.h b/src/knowitapp.h
index f876202..eb98f58 100644
--- a/src/knowitapp.h
+++ b/src/knowitapp.h
@@ -22,18 +22,19 @@
class KnowitApplication : public KUniqueApplication
{
Q_OBJECT
+ TQ_OBJECT
public:
KnowitApplication(bool allowStyles = true, bool GUIEnabled = true);
~KnowitApplication();
/** Commits all Application-relevant data on shutdown.
*
* This function is called when the QSessionManager wants to close the
* Application. It is reimplemented to set the boolean sessionClose flag.
*
* @param sm The QSessionManager object.
*/
- virtual void commitData(QSessionManager& sm);
+ virtual void commitData(TQSessionManager& sm);
/** Returns TRUE if the Application is closed by the session manager. */
bool closeByLogout() {return(mcloseByLogout);}
@@ -22,18 +22,19 @@
/** Commits all Application-relevant data on shutdown.
*
- * This function is called when the QSessionManager wants to close the
+ * This function is called when the TQSessionManager wants to close the
* Application. It is reimplemented to set the boolean sessionClose flag.
*
@@ -22,18 +22,19 @@
* Application. It is reimplemented to set the boolean sessionClose flag.
*
- * @param sm The QSessionManager object.
+ * @param sm The TQSessionManager object.
*/